/*
 *   Copyright 2010 Brian Rosenberger (Brutex Network)
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package net.brutex.xservices.types;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

/**
 * Generic key/ value pairs.
 *
 * @author Brian Rosenberger
 */
@XmlRootElement
public class ReplacePattern {

    /**
     * Search string.
     */
    @XmlElement(required=true)
    public String search ="";

    /**
     * Replace string.
     */
    @XmlElement(required=true)
    public String replace="";

    /**
     * Converts a Map&lt;String, String&gt; into a list of
     * ReplacePattern.
     * @param map   The map to convert
     * @return      A list of key/value pairs
     */
    public static List<ReplacePattern> createAntPropertyList(Map<String, String> map) {
        List<ReplacePattern> list = new ArrayList<ReplacePattern>();
        for(Map.Entry<String, String> e : map.entrySet()) {
            list.add(new ReplacePattern(e.getKey(), e.getValue()));
        }
        return list;
    }

    /**
     * Creates a new ReplacePattern.
     * @param name
     * @param value
     */
    public ReplacePattern(String search, String replace) {
        this.search = search;
        this.replace = replace;
    }

    /**
     * Creates a new ReplacePattern.
     */
    public ReplacePattern() {
    }
    

}
